#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'octave-qscintilla.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/src/m-editor/octave-qscintilla.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'octave-qscintilla.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__octave_qscintilla_t {
    QByteArrayData data[30];
    char stringdata0[591];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__octave_qscintilla_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__octave_qscintilla_t qt_meta_stringdata_octave__octave_qscintilla = {
    {
QT_MOC_LITERAL(0, 0, 25), // "octave::octave_qscintilla"
QT_MOC_LITERAL(1, 26, 34), // "execute_command_in_terminal_s..."
QT_MOC_LITERAL(2, 61, 0), // ""
QT_MOC_LITERAL(3, 62, 26), // "create_context_menu_signal"
QT_MOC_LITERAL(4, 89, 6), // "QMenu*"
QT_MOC_LITERAL(5, 96, 24), // "context_menu_edit_signal"
QT_MOC_LITERAL(6, 121, 21), // "qsci_has_focus_signal"
QT_MOC_LITERAL(7, 143, 13), // "status_update"
QT_MOC_LITERAL(8, 157, 15), // "show_doc_signal"
QT_MOC_LITERAL(9, 173, 35), // "context_menu_break_condition_..."
QT_MOC_LITERAL(10, 209, 23), // "context_menu_break_once"
QT_MOC_LITERAL(11, 233, 28), // "ctx_menu_run_finished_signal"
QT_MOC_LITERAL(12, 262, 15), // "QTemporaryFile*"
QT_MOC_LITERAL(13, 278, 34), // "focus_console_after_command_s..."
QT_MOC_LITERAL(14, 313, 17), // "interpreter_event"
QT_MOC_LITERAL(15, 331, 12), // "fcn_callback"
QT_MOC_LITERAL(16, 344, 3), // "fcn"
QT_MOC_LITERAL(17, 348, 13), // "meth_callback"
QT_MOC_LITERAL(18, 362, 4), // "meth"
QT_MOC_LITERAL(19, 367, 21), // "ctx_menu_run_finished"
QT_MOC_LITERAL(20, 389, 16), // "contextmenu_help"
QT_MOC_LITERAL(21, 406, 15), // "contextmenu_doc"
QT_MOC_LITERAL(22, 422, 20), // "contextmenu_help_doc"
QT_MOC_LITERAL(23, 443, 16), // "contextmenu_edit"
QT_MOC_LITERAL(24, 460, 15), // "contextmenu_run"
QT_MOC_LITERAL(25, 476, 26), // "contextmenu_run_temp_error"
QT_MOC_LITERAL(26, 503, 27), // "contextmenu_break_condition"
QT_MOC_LITERAL(27, 531, 22), // "contextmenu_break_once"
QT_MOC_LITERAL(28, 554, 12), // "text_changed"
QT_MOC_LITERAL(29, 567, 23) // "cursor_position_changed"

    },
    "octave::octave_qscintilla\0"
    "execute_command_in_terminal_signal\0\0"
    "create_context_menu_signal\0QMenu*\0"
    "context_menu_edit_signal\0qsci_has_focus_signal\0"
    "status_update\0show_doc_signal\0"
    "context_menu_break_condition_signal\0"
    "context_menu_break_once\0"
    "ctx_menu_run_finished_signal\0"
    "QTemporaryFile*\0focus_console_after_command_signal\0"
    "interpreter_event\0fcn_callback\0fcn\0"
    "meth_callback\0meth\0ctx_menu_run_finished\0"
    "contextmenu_help\0contextmenu_doc\0"
    "contextmenu_help_doc\0contextmenu_edit\0"
    "contextmenu_run\0contextmenu_run_temp_error\0"
    "contextmenu_break_condition\0"
    "contextmenu_break_once\0text_changed\0"
    "cursor_position_changed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__octave_qscintilla[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  129,    2, 0x06 /* Public */,
       3,    1,  132,    2, 0x06 /* Public */,
       5,    1,  135,    2, 0x06 /* Public */,
       6,    1,  138,    2, 0x06 /* Public */,
       7,    2,  141,    2, 0x06 /* Public */,
       8,    1,  146,    2, 0x06 /* Public */,
       9,    1,  149,    2, 0x06 /* Public */,
      10,    1,  152,    2, 0x06 /* Public */,
      11,    6,  155,    2, 0x06 /* Public */,
      13,    0,  168,    2, 0x06 /* Public */,
      14,    1,  169,    2, 0x06 /* Public */,
      14,    1,  172,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    6,  175,    2, 0x08 /* Private */,
      20,    1,  188,    2, 0x08 /* Private */,
      21,    1,  191,    2, 0x08 /* Private */,
      22,    1,  194,    2, 0x08 /* Private */,
      23,    1,  197,    2, 0x08 /* Private */,
      24,    1,  200,    2, 0x08 /* Private */,
      25,    0,  203,    2, 0x08 /* Private */,
      26,    1,  204,    2, 0x08 /* Private */,
      27,    1,  207,    2, 0x08 /* Private */,
      28,    0,  210,    2, 0x08 /* Private */,
      29,    2,  211,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 12, 0x80000000 | 12, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, 0x80000000 | 17,   18,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 12, 0x80000000 | 12, QMetaType::Bool, QMetaType::Bool,    2,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QPoint,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,

       0        // eod
};

void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        octave_qscintilla *_t = static_cast<octave_qscintilla *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->execute_command_in_terminal_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->create_context_menu_signal((*reinterpret_cast< QMenu*(*)>(_a[1]))); break;
        case 2: _t->context_menu_edit_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->qsci_has_focus_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->status_update((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->context_menu_break_condition_signal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->context_menu_break_once((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->ctx_menu_run_finished_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[3])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
        case 9: _t->focus_console_after_command_signal(); break;
        case 10: _t->interpreter_event((*reinterpret_cast< const fcn_callback(*)>(_a[1]))); break;
        case 11: _t->interpreter_event((*reinterpret_cast< const meth_callback(*)>(_a[1]))); break;
        case 12: _t->ctx_menu_run_finished((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[3])),(*reinterpret_cast< QTemporaryFile*(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
        case 13: _t->contextmenu_help((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->contextmenu_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->contextmenu_help_doc((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->contextmenu_edit((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->contextmenu_run((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->contextmenu_run_temp_error(); break;
        case 19: _t->contextmenu_break_condition((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->contextmenu_break_once((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 21: _t->text_changed(); break;
        case 22: _t->cursor_position_changed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (octave_qscintilla::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::execute_command_in_terminal_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(QMenu * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::create_context_menu_signal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_edit_signal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::qsci_has_focus_signal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::status_update)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::show_doc_signal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_break_condition_signal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::context_menu_break_once)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(bool , int , QTemporaryFile * , QTemporaryFile * , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::ctx_menu_run_finished_signal)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::focus_console_after_command_signal)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(const fcn_callback & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::interpreter_event)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (octave_qscintilla::*_t)(const meth_callback & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&octave_qscintilla::interpreter_event)) {
                *result = 11;
                return;
            }
        }
    }
}

const QMetaObject octave::octave_qscintilla::staticMetaObject = {
    { &QsciScintilla::staticMetaObject, qt_meta_stringdata_octave__octave_qscintilla.data,
      qt_meta_data_octave__octave_qscintilla,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::octave_qscintilla::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::octave_qscintilla::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__octave_qscintilla.stringdata0))
        return static_cast<void*>(this);
    return QsciScintilla::qt_metacast(_clname);
}

int octave::octave_qscintilla::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QsciScintilla::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void octave::octave_qscintilla::execute_command_in_terminal_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::octave_qscintilla::create_context_menu_signal(QMenu * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::octave_qscintilla::context_menu_edit_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::octave_qscintilla::qsci_has_focus_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void octave::octave_qscintilla::status_update(bool _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void octave::octave_qscintilla::show_doc_signal(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void octave::octave_qscintilla::context_menu_break_condition_signal(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void octave::octave_qscintilla::context_menu_break_once(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void octave::octave_qscintilla::ctx_menu_run_finished_signal(bool _t1, int _t2, QTemporaryFile * _t3, QTemporaryFile * _t4, bool _t5, bool _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void octave::octave_qscintilla::focus_console_after_command_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void octave::octave_qscintilla::interpreter_event(const fcn_callback & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void octave::octave_qscintilla::interpreter_event(const meth_callback & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
